@@ -13,7 +13,7 @@ class RequestHandler:
                  universal_parameters: dict = None,
                  universal_headers: dict = None):
         """
-        Create a reuseable request handler
+        Create a reusable request handler
         Set universal parameters and headers used for all requests
         Reuses session for all requests
 
@@ -67,37 +67,42 @@ class RequestHandler:
         return headers
 
     @request_handler_request
-    def get(self, url: str, **kwargs) -> requests.Response:
+    def get(self, url: str, use_proxy: bool = False, **kwargs) -> requests.Response:
         """
         Return the requests.Response object from a GET request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: A Requests.Response object
         :rtype: requests.Response
         """
-        return get(url=url, session=self._session, **kwargs)
+        return get(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def get_json(self, url: str, **kwargs) -> dict:
+    def get_json(self, url: str, use_proxy: bool = False, **kwargs) -> dict:
         """
         Return the JSON data from a GET request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: a JSON dictionary
         :rtype: dict
         """
-        return get_json(url=url, session=self._session, **kwargs)
+        return get_json(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def get_object(self, url: str, model: type, **kwargs) -> Union[object, None]:
+    def get_object(self, url: str, model: type, sub_keys: List = None, extract_list: bool = False,
+                   use_proxy: bool = False, **kwargs) -> Union[object, None]:
         """
         Parse the JSON data from a GET request into an object
         Automatically appends base URL, universal params and headers, reuses session
@@ -106,45 +111,91 @@ class RequestHandler:
         :type url: str
         :param model: a Pydantic model to generate from the response JSON data
         :type model: type
+        :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+        :type sub_keys: list, optional
+        :param extract_list: If top-level of JSON is a list, whether to convert each list item into model or treat entire JSON as a whole object
+        :type extract_list: bool
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: an object
         :rtype: object
         """
-        return get_object(url=url, model=model, session=self._session, **kwargs)
+        return get_object(url=url, model=model, sub_keys=sub_keys, extract_list=extract_list, session=self._session,
+                          use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def post(self, url: str, **kwargs) -> requests.Response:
+    def options(self, url: str, use_proxy: bool = False, **kwargs) -> requests.Response:
+        """
+        Return the requests.Response object from an OPTIONS request
+        Automatically appends base URL, universal params and headers, reuses session
+
+        :param url: URL endpoint to append to base URL
+        :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
+        :param kwargs: Keyword arguments to pass to Requests library
+        :type kwargs: dict, optional
+        :return: A Requests.Response object
+        :rtype: requests.Response
+        """
+        return options(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
+
+    @request_handler_request
+    def head(self, url: str, use_proxy: bool = False, **kwargs) -> requests.Response:
+        """
+        Return the requests.Response object from a HEAD request
+        Automatically appends base URL, universal params and headers, reuses session
+
+        :param url: URL endpoint to append to base URL
+        :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
+        :param kwargs: Keyword arguments to pass to Requests library
+        :type kwargs: dict, optional
+        :return: A Requests.Response object
+        :rtype: requests.Response
+        """
+        return head(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
+
+    @request_handler_request
+    def post(self, url: str, use_proxy: bool = False, **kwargs) -> requests.Response:
         """
         Return the requests.Response object from a POST request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: A Requests.Response object
         :rtype: requests.Response
         """
-        return post(url=url, session=self._session, **kwargs)
+        return post(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def post_json(self, url: str, **kwargs) -> dict:
+    def post_json(self, url: str, use_proxy: bool = False, **kwargs) -> dict:
         """
         Return the JSON data from a POST request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: a JSON dictionary
         :rtype: dict
         """
-        return post_json(url=url, session=self._session, **kwargs)
+        return post_json(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def post_object(self, url: str, model: type, **kwargs) -> Union[object, None]:
+    def post_object(self, url: str, model: type, sub_keys: List = None, extract_list: bool = False,
+                    use_proxy: bool = False, **kwargs) -> Union[object, None]:
         """
         Parse the JSON data from a POST request into an object
         Automatically appends base URL, universal params and headers, reuses session
@@ -153,45 +204,57 @@ class RequestHandler:
         :type url: str
         :param model: a Pydantic model to generate from the response JSON data
         :type model: type
+        :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+        :type sub_keys: list, optional
+        :param extract_list: If top-level of JSON is a list, whether to convert each list item into model or treat entire JSON as a whole object
+        :type extract_list: bool
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: an object
         :rtype: object
         """
-        return post_object(url=url, model=model, session=self._session, **kwargs)
+        return post_object(url=url, model=model, sub_keys=sub_keys, extract_list=extract_list, session=self._session,
+                           use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def put(self, url: str, **kwargs) -> requests.Response:
+    def put(self, url: str, use_proxy: bool = False, **kwargs) -> requests.Response:
         """
         Return the requests.Response object from a PUT request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: A Requests.Response object
         :rtype: requests.Response
         """
-        return put(url=url, session=self._session, **kwargs)
+        return put(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def put_json(self, url: str, **kwargs) -> dict:
+    def put_json(self, url: str, use_proxy: bool = False, **kwargs) -> dict:
         """
         Return the JSON data from a PUT request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: a JSON dictionary
         :rtype: dict
         """
-        return put_json(url=url, session=self._session, **kwargs)
+        return put_json(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def put_object(self, url: str, model: type, **kwargs) -> Union[object, None]:
+    def put_object(self, url: str, model: type, sub_keys: List = None, extract_list: bool = False,
+                   use_proxy: bool = False, **kwargs) -> Union[object, None]:
         """
         Parse the JSON data from a PUT request into an object
         Automatically appends base URL, universal params and headers, reuses session
@@ -200,45 +263,57 @@ class RequestHandler:
         :type url: str
         :param model: a Pydantic model to generate from the response JSON data
         :type model: type
+        :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+        :type sub_keys: list, optional
+        :param extract_list: If top-level of JSON is a list, whether to convert each list item into model or treat entire JSON as a whole object
+        :type extract_list: bool
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: an object
         :rtype: object
         """
-        return put_object(url=url, model=model, session=self._session, **kwargs)
+        return put_object(url=url, model=model, sub_keys=sub_keys, extract_list=extract_list, session=self._session,
+                          use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def patch(self, url: str, **kwargs) -> requests.Response:
+    def patch(self, url: str, use_proxy: bool = False, **kwargs) -> requests.Response:
         """
         Return the requests.Response object from a PATCH request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: A Requests.Response object
         :rtype: requests.Response
         """
-        return patch(url=url, session=self._session, **kwargs)
+        return patch(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def patch_json(self, url: str, **kwargs) -> dict:
+    def patch_json(self, url: str, use_proxy: bool = False, **kwargs) -> dict:
         """
         Return the JSON data from a PATCH request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: a JSON dictionary
         :rtype: dict
         """
-        return patch_json(url=url, session=self._session, **kwargs)
+        return patch_json(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def patch_object(self, url: str, model: type, **kwargs) -> Union[object, None]:
+    def patch_object(self, url: str, model: type, sub_keys: List = None, extract_list: bool = False,
+                     use_proxy: bool = False, **kwargs) -> Union[object, None]:
         """
         Parse the JSON data from a PATCH request into an object
         Automatically appends base URL, universal params and headers, reuses session
@@ -247,45 +322,57 @@ class RequestHandler:
         :type url: str
         :param model: a Pydantic model to generate from the response JSON data
         :type model: type
+        :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+        :type sub_keys: list, optional
+        :param extract_list: If top-level of JSON is a list, whether to convert each list item into model or treat entire JSON as a whole object
+        :type extract_list: bool
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: an object
         :rtype: object
         """
-        return patch_object(url=url, model=model, session=self._session, **kwargs)
+        return patch_object(url=url, model=model, sub_keys=sub_keys, extract_list=extract_list, session=self._session,
+                            use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def delete(self, url: str, **kwargs) -> requests.Response:
+    def delete(self, url: str, use_proxy: bool = False, **kwargs) -> requests.Response:
         """
         Return the requests.Response object from a DELETE request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: A Requests.Response object
         :rtype: requests.Response
         """
-        return delete(url=url, session=self._session, **kwargs)
+        return delete(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def delete_json(self, url: str, **kwargs) -> dict:
+    def delete_json(self, url: str, use_proxy: bool = False, **kwargs) -> dict:
         """
         Return the JSON data from a DELETE request
         Automatically appends base URL, universal params and headers, reuses session
 
         :param url: URL endpoint to append to base URL
         :type url: str
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: a JSON dictionary
         :rtype: dict
         """
-        return delete_json(url=url, session=self._session, **kwargs)
+        return delete_json(url=url, session=self._session, use_proxy=use_proxy, **kwargs)
 
     @request_handler_request
-    def delete_object(self, url: str, model: type, **kwargs) -> Union[object, None]:
+    def delete_object(self, url: str, model: type, sub_keys: List = None, extract_list: bool = False,
+                      use_proxy: bool = False, **kwargs) -> Union[object, None]:
         """
         Parse the JSON data from a DELETE request into an object
         Automatically appends base URL, universal params and headers, reuses session
@@ -294,12 +381,20 @@ class RequestHandler:
         :type url: str
         :param model: a Pydantic model to generate from the response JSON data
         :type model: type
+        :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+        :type sub_keys: list, optional
+        :param extract_list: If top-level of JSON is a list, whether to convert each list item into model or treat entire JSON as a whole object
+        :type extract_list: bool
+        :param use_proxy: whether to use a random proxy for your request (default False)
+        :type use_proxy: bool, optional
         :param kwargs: Keyword arguments to pass to Requests library
         :type kwargs: dict, optional
         :return: an object
         :rtype: object
         """
-        return delete_object(url=url, model=model, session=self._session, **kwargs)
+        return delete_object(url=url, model=model, sub_keys=sub_keys, extract_list=extract_list, session=self._session,
+                             use_proxy=use_proxy, **kwargs)
+
 
 class ApiTokenRequestHandler(RequestHandler):
     def __init__(self,
@@ -310,7 +405,7 @@ class ApiTokenRequestHandler(RequestHandler):
                  universal_headers: dict = None,
                  include_key_in_header: bool = False):
         """
-        Create a reuseable request handler to handle requests requiring API tokens
+        Create a reusable request handler to handle requests requiring API tokens
         Set universal parameters and headers used for all requests
         Reuses session for all requests
 
@@ -322,7 +417,7 @@ class ApiTokenRequestHandler(RequestHandler):
         :type universal_parameters: dict, optional
         :param api_token: The API token needed for each request
         :type api_token: str
-        :param api_token_keyword: The name of the API token parameter expected by the API (i.e "token", "key", "api_key")
+        :param api_token_keyword: Name of the API token parameter expected by the API (i.e "token", "key", "api_key")
         :type api_token_keyword: str
         :param include_key_in_header: Whether to include API token in header (included as URL param otherwise)
         :type include_key_in_header: bool, optional
@@ -351,7 +446,7 @@ class OAuth2RequestHandler(RequestHandler):
                  universal_parameters: dict = None,
                  universal_headers: dict = None):
         """
-        Create a reuseable request handler to handle requests requiring API tokens
+        Create a reusable request handler to handle requests requiring API tokens
         Set universal parameters and headers used for all requests
         Reuses session for all requests
 
@@ -414,11 +509,15 @@ class OAuth2RequestHandler(RequestHandler):
         return access_token
 
     def _make_headers(self, local_headers: dict = None) -> dict:
-        headers = RequestHandler._make_headers(self, local_headers=local_headers)
+        """
+        Retrieve access token to make headers for an OAuth2 request
+
+        :param local_headers:
+        :return:
+        """
+        headers = super()._make_headers(local_headers=local_headers)
 
         access_token = self._get_access_token()
         headers['Authorization'] = f"Bearer {access_token}"
 
         return headers
-
-
